@@ -53,12 +53,7 @@ GType                     gs_listener_x11_get_type                  (void);
 GSListenerX11            *gs_listener_x11_new                       (void);
 gboolean                  gs_listener_x11_acquire                   (GSListenerX11 *listener);
 void
-                          gs_listener_x11_set_timeout               (GSListenerX11 *listener,
-                                                                     gint           timeout);
-void                      gs_listener_x11_set_saver_enabled         (GSListenerX11 *listener,
-                                                                     gboolean       enabled);
-void                      gs_listener_x11_set_activation_enabled    (GSListenerX11 *listener,
-                                                                     gboolean       enabled);
+                          gs_listener_x11_set_timeout               (GSListenerX11 *listener);
 G_END_DECLS
 
 #endif /* SRC_GS_LISTENER_X11_H_ */
