@@ -35,8 +35,7 @@
 #include "gs-grab.h"
 #include "gs-job.h"
 #include "gs-manager.h"
-#include "gs-prefs.h"        /* for GSSaverMode */
-#include "gs-theme-manager.h"
+#include "gs-prefs.h"
 #include "gs-window.h"
 #include "xfce-bg.h"
 
@@ -48,26 +47,11 @@ struct GSManagerPrivate {
     GSList         *windows;
     GHashTable     *jobs;
 
-    GSThemeManager *theme_manager;
     XfceBG         *bg;
 
     /* Policy */
-    glong           lock_timeout;
-    glong           cycle_timeout;
-    glong           logout_timeout;
-
-    guint           saver_enabled : 1;
-    guint           lock_enabled : 1;
-    guint           lock_with_saver_enabled : 1;
-    guint           logout_enabled : 1;
-    guint           keyboard_enabled : 1;
-    guint           user_switch_enabled : 1;
-    guint           status_message_enabled : 1;
+    GSPrefs         *prefs;
     guint           throttled : 1;
-
-    char           *logout_command;
-    char           *keyboard_command;
-
     char           *status_message;
 
     /* State */
@@ -82,8 +66,6 @@ struct GSManagerPrivate {
     guint           lock_timeout_id;
     guint           cycle_timeout_id;
 
-    GSList         *themes;
-    GSSaverMode     saver_mode;
     GSGrab         *grab;
     guint           deepsleep_idle_id;
     gboolean        deepsleep;
@@ -99,17 +81,6 @@ enum {
 
 enum {
     PROP_0,
-    PROP_LOCK_ENABLED,
-    PROP_LOCK_WITH_SAVER_ENABLED,
-    PROP_LOGOUT_ENABLED,
-    PROP_USER_SWITCH_ENABLED,
-    PROP_KEYBOARD_ENABLED,
-    PROP_LOCK_TIMEOUT,
-    PROP_CYCLE_TIMEOUT,
-    PROP_LOGOUT_TIMEOUT,
-    PROP_LOGOUT_COMMAND,
-    PROP_KEYBOARD_COMMAND,
-    PROP_STATUS_MESSAGE_ENABLED,
     PROP_STATUS_MESSAGE,
     PROP_ACTIVE,
     PROP_THROTTLED,
@@ -147,31 +118,6 @@ manager_add_job_for_window (GSManager *manager,
     g_hash_table_insert (manager->priv->jobs, window, job);
 }
 
-static const char *
-select_theme (GSManager *manager) {
-    const char *theme = NULL;
-
-    g_return_val_if_fail (manager != NULL, NULL);
-    g_return_val_if_fail (GS_IS_MANAGER (manager), NULL);
-
-    if (!manager->priv->saver_enabled ||
-            manager->priv->saver_mode == GS_MODE_BLANK_ONLY) {
-        return NULL;
-    }
-
-    if (manager->priv->themes) {
-        int number = 0;
-
-        if (manager->priv->saver_mode == GS_MODE_RANDOM) {
-            g_random_set_seed (time (NULL));
-            number = g_random_int_range (0, g_slist_length (manager->priv->themes));
-        }
-        theme = g_slist_nth_data (manager->priv->themes, number);
-    }
-
-    return theme;
-}
-
 static GSJob *
 lookup_job_for_window (GSManager *manager,
                        GSWindow  *window) {
@@ -212,56 +158,24 @@ manager_maybe_start_job_for_window (GSManager *manager,
         gs_debug ("Job not found for window");
         return;
     }
-
-    if (!manager->priv->dialog_up) {
-        if (!manager->priv->throttled) {
-            if (!gs_job_is_running (job)) {
-                if (!gs_window_is_obscured (window)) {
-                    gs_debug ("Starting job for window");
-                    gs_job_start (job);
-                } else {
-                    gs_debug ("Window is obscured deferring start of job");
-                }
-            } else {
-                gs_debug ("Not starting job because job is running");
-            }
-        } else {
-            gs_debug ("Not starting job because throttled");
-        }
-    } else {
+    if (manager->priv->dialog_up) {
         gs_debug ("Not starting job because dialog is up");
+        return;
     }
-}
-
-static void
-manager_select_theme_for_job (GSManager *manager,
-                              GSJob     *job) {
-    const char *theme;
-
-    theme = select_theme (manager);
-
-    if (theme != NULL) {
-        GSThemeInfo    *info;
-        const char     *command;
-
-        command = NULL;
-
-        info = gs_theme_manager_lookup_theme_info (manager->priv->theme_manager, theme);
-        if (info != NULL) {
-            command = gs_theme_info_get_exec (info);
-        } else {
-            gs_debug ("Could not find information for theme: %s",
-                      theme);
-        }
-
-        gs_job_set_command (job, command);
-
-        if (info != NULL) {
-            gs_theme_info_unref (info);
-        }
-    } else {
-        gs_job_set_command (job, NULL);
+    if (manager->priv->throttled) {
+        gs_debug ("Not starting job because throttled");
+        return;
     }
+    if (gs_job_is_running (job)) {
+        gs_debug ("Not starting job because job is running");
+        return;
+    }
+    if (gs_window_is_obscured (window)) {
+        gs_debug ("Window is obscured deferring start of job");
+        return;
+    }
+    gs_debug ("Starting job for window");
+    gs_job_start (job);
 }
 
 static void
@@ -269,7 +183,6 @@ cycle_job (GSWindow  *window,
            GSJob     *job,
            GSManager *manager) {
     gs_job_stop (job);
-    manager_select_theme_for_job (manager, job);
     manager_maybe_start_job_for_window (manager, window);
 }
 
@@ -338,37 +251,6 @@ manager_stop_jobs (GSManager *manager) {
     manager->priv->jobs = NULL;
 }
 
-void
-gs_manager_set_mode (GSManager  *manager,
-                     GSSaverMode mode) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    manager->priv->saver_mode = mode;
-}
-
-static void
-free_themes (GSManager *manager) {
-    if (manager->priv->themes) {
-        g_slist_foreach (manager->priv->themes, (GFunc)g_free, NULL);
-        g_slist_free (manager->priv->themes);
-    }
-}
-
-void
-gs_manager_set_themes (GSManager *manager,
-                       GSList    *themes) {
-    GSList *l;
-
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    free_themes (manager);
-    manager->priv->themes = NULL;
-
-    for (l = themes; l; l = l->next) {
-        manager->priv->themes = g_slist_append (manager->priv->themes, g_strdup (l->data));
-    }
-}
-
 void
 gs_manager_set_throttled (GSManager *manager,
                           gboolean   throttled) {
@@ -453,90 +335,10 @@ gs_manager_set_saver_active (GSManager *manager,
     }
 }
 
-void
-gs_manager_set_saver_enabled (GSManager *manager,
-                              gboolean   saver_enabled) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->saver_enabled != saver_enabled) {
-        manager->priv->saver_enabled = saver_enabled;
-    }
-}
-
-void
-gs_manager_set_lock_enabled (GSManager *manager,
-                             gboolean   lock_enabled) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->lock_enabled != lock_enabled) {
-        manager->priv->lock_enabled = lock_enabled;
-    }
-}
-
-void
-gs_manager_set_lock_with_saver_enabled (GSManager *manager,
-                             gboolean   lock_with_saver_enabled) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->lock_with_saver_enabled != lock_with_saver_enabled) {
-        manager->priv->lock_with_saver_enabled = lock_with_saver_enabled;
-    }
-}
-
-void
-gs_manager_set_logout_enabled (GSManager *manager,
-                               gboolean   logout_enabled) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->logout_enabled != logout_enabled) {
-        GSList *l;
-
-        manager->priv->logout_enabled = logout_enabled;
-        for (l = manager->priv->windows; l; l = l->next) {
-            gs_window_set_logout_enabled (l->data, logout_enabled);
-        }
-    }
-}
-
-void
-gs_manager_set_keyboard_enabled (GSManager *manager,
-                                 gboolean   enabled) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->keyboard_enabled != enabled) {
-        GSList *l;
-
-        manager->priv->keyboard_enabled = enabled;
-        for (l = manager->priv->windows; l; l = l->next) {
-            gs_window_set_keyboard_enabled (l->data, enabled);
-        }
-    }
-}
-
-void
-gs_manager_set_user_switch_enabled (GSManager *manager,
-                                    gboolean   user_switch_enabled) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->user_switch_enabled != user_switch_enabled) {
-        GSList *l;
-
-        manager->priv->user_switch_enabled = user_switch_enabled;
-        for (l = manager->priv->windows; l; l = l->next) {
-            gs_window_set_user_switch_enabled (l->data, user_switch_enabled);
-        }
-    }
-}
-
 static gboolean
 activate_lock_timeout (GSManager *manager) {
-    if (manager->priv->lock_enabled &&
-            manager->priv->lock_with_saver_enabled)
-    {
-        gs_debug ("Locking screen after idling timeout");
-        gs_manager_set_lock_active (manager, TRUE);
-    }
-
+    gs_debug ("Locking screen after idling timeout");
+    gs_manager_set_lock_active (manager, TRUE);
     manager->priv->lock_timeout_id = 0;
 
     return FALSE;
@@ -553,12 +355,12 @@ remove_lock_timer (GSManager *manager) {
 static void
 add_lock_timer (GSManager *manager,
                 glong      timeout) {
-    if (!manager->priv->lock_enabled)
-        return;
-    if (!manager->priv->lock_with_saver_enabled)
-        return;
-
     gboolean locked;
+
+    if (!manager->priv->prefs->lock_enabled)
+        return;
+    if (!manager->priv->prefs->lock_with_saver_enabled)
+        return;
     gs_manager_get_lock_active (manager, &locked);
     if (locked)
         return;
@@ -569,99 +371,6 @@ add_lock_timer (GSManager *manager,
                                                     manager);
 }
 
-void
-gs_manager_set_lock_timeout (GSManager *manager,
-                             glong      lock_timeout) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->lock_timeout != lock_timeout) {
-        manager->priv->lock_timeout = lock_timeout;
-
-        if (manager->priv->active
-                && !manager->priv->lock_active
-                && (lock_timeout >= 0)) {
-            glong elapsed = (time (NULL) - manager->priv->activate_time) * 1000;
-
-            remove_lock_timer (manager);
-
-            if (elapsed >= lock_timeout) {
-                activate_lock_timeout (manager);
-            } else {
-                add_lock_timer (manager, lock_timeout - elapsed);
-            }
-        }
-    }
-}
-
-void
-gs_manager_set_logout_timeout (GSManager *manager,
-                               glong      logout_timeout) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->logout_timeout != logout_timeout) {
-        GSList *l;
-
-        manager->priv->logout_timeout = logout_timeout;
-        for (l = manager->priv->windows; l; l = l->next) {
-            gs_window_set_logout_timeout (l->data, logout_timeout);
-        }
-    }
-}
-
-void
-gs_manager_set_logout_command (GSManager  *manager,
-                               const char *command) {
-    GSList *l;
-
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    g_free (manager->priv->logout_command);
-
-    if (command) {
-        manager->priv->logout_command = g_strdup (command);
-    } else {
-        manager->priv->logout_command = NULL;
-    }
-
-    for (l = manager->priv->windows; l; l = l->next) {
-        gs_window_set_logout_command (l->data, manager->priv->logout_command);
-    }
-}
-
-void
-gs_manager_set_keyboard_command (GSManager  *manager,
-                                 const char *command) {
-    GSList *l;
-
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    g_free (manager->priv->keyboard_command);
-
-    if (command) {
-        manager->priv->keyboard_command = g_strdup (command);
-    } else {
-        manager->priv->keyboard_command = NULL;
-    }
-
-    for (l = manager->priv->windows; l; l = l->next) {
-        gs_window_set_keyboard_command (l->data, manager->priv->keyboard_command);
-    }
-}
-
-void
-gs_manager_set_status_message_enabled (GSManager  *manager,
-                                       gboolean    status_message_enabled) {
-    GSList *l;
-
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    manager->priv->status_message_enabled = status_message_enabled;
-
-    for (l = manager->priv->windows; l; l = l->next) {
-        gs_window_set_status_message_enabled (l->data, manager->priv->status_message_enabled);
-    }
-}
-
 void
 gs_manager_set_status_message (GSManager  *manager,
                                const char *message) {
@@ -683,20 +392,16 @@ gs_manager_cycle (GSManager *manager) {
     g_return_val_if_fail (manager != NULL, FALSE);
     g_return_val_if_fail (GS_IS_MANAGER (manager), FALSE);
 
-    gs_debug ("Cycling jobs");
-
     if (!manager->priv->active) {
         return FALSE;
     }
-
     if (manager->priv->dialog_up) {
         return FALSE;
     }
-
     if (manager->priv->throttled) {
         return FALSE;
     }
-
+    gs_debug ("Cycling jobs");
     manager_cycle_jobs (manager);
 
     return TRUE;
@@ -730,31 +435,6 @@ add_cycle_timer (GSManager *manager,
                                                      manager);
 }
 
-void
-gs_manager_set_cycle_timeout (GSManager *manager,
-                              glong      cycle_timeout) {
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (manager->priv->cycle_timeout != cycle_timeout) {
-        manager->priv->cycle_timeout = cycle_timeout;
-
-        if (manager->priv->active && (cycle_timeout >= 0)) {
-            glong timeout;
-            glong elapsed = (time (NULL) - manager->priv->activate_time) * 1000;
-
-            remove_cycle_timer (manager);
-
-            if (elapsed >= cycle_timeout) {
-                timeout = 0;
-            } else {
-                timeout = cycle_timeout - elapsed;
-            }
-
-            add_cycle_timer (manager, timeout);
-        }
-    }
-}
-
 static void
 gs_manager_set_property (GObject      *object,
                          guint         prop_id,
@@ -768,41 +448,11 @@ gs_manager_set_property (GObject      *object,
         case PROP_THROTTLED:
             gs_manager_set_throttled (self, g_value_get_boolean (value));
             break;
-        case PROP_LOCK_ENABLED:
-            gs_manager_set_lock_enabled (self, g_value_get_boolean (value));
-            break;
-        case PROP_LOCK_WITH_SAVER_ENABLED:
-            gs_manager_set_lock_with_saver_enabled (self, g_value_get_boolean (value));
-            break;
-        case PROP_LOCK_TIMEOUT:
-            gs_manager_set_lock_timeout (self, g_value_get_long (value));
-            break;
-        case PROP_LOGOUT_ENABLED:
-            gs_manager_set_logout_enabled (self, g_value_get_boolean (value));
-            break;
-        case PROP_KEYBOARD_ENABLED:
-            gs_manager_set_keyboard_enabled (self, g_value_get_boolean (value));
-            break;
-        case PROP_USER_SWITCH_ENABLED:
-            gs_manager_set_user_switch_enabled (self, g_value_get_boolean (value));
-            break;
-        case PROP_LOGOUT_TIMEOUT:
-            gs_manager_set_logout_timeout (self, g_value_get_long (value));
-            break;
-        case PROP_LOGOUT_COMMAND:
-            gs_manager_set_logout_command (self, g_value_get_string (value));
-            break;
-        case PROP_KEYBOARD_COMMAND:
-            gs_manager_set_keyboard_command (self, g_value_get_string (value));
-            break;
-        case PROP_STATUS_MESSAGE_ENABLED:
-            gs_manager_set_status_message_enabled (self, g_value_get_boolean (value));
-            break;
         case PROP_STATUS_MESSAGE:
             gs_manager_set_status_message (self, g_value_get_string (value));
             break;
-        case PROP_CYCLE_TIMEOUT:
-            gs_manager_set_cycle_timeout (self, g_value_get_long (value));
+        case PROP_ACTIVE:
+            gs_manager_set_active (self, g_value_get_boolean (value));
             break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -823,42 +473,9 @@ gs_manager_get_property (GObject    *object,
         case PROP_THROTTLED:
             g_value_set_boolean (value, self->priv->throttled);
             break;
-        case PROP_LOCK_ENABLED:
-            g_value_set_boolean (value, self->priv->lock_enabled);
-            break;
-        case PROP_LOCK_WITH_SAVER_ENABLED:
-            g_value_set_boolean (value, self->priv->lock_with_saver_enabled);
-            break;
-        case PROP_LOCK_TIMEOUT:
-            g_value_set_long (value, self->priv->lock_timeout);
-            break;
-        case PROP_LOGOUT_ENABLED:
-            g_value_set_boolean (value, self->priv->logout_enabled);
-            break;
-        case PROP_KEYBOARD_ENABLED:
-            g_value_set_boolean (value, self->priv->keyboard_enabled);
-            break;
-        case PROP_USER_SWITCH_ENABLED:
-            g_value_set_boolean (value, self->priv->user_switch_enabled);
-            break;
-        case PROP_LOGOUT_TIMEOUT:
-            g_value_set_long (value, self->priv->logout_timeout);
-            break;
-        case PROP_LOGOUT_COMMAND:
-            g_value_set_string (value, self->priv->logout_command);
-            break;
-        case PROP_KEYBOARD_COMMAND:
-            g_value_set_string (value, self->priv->keyboard_command);
-            break;
-        case PROP_STATUS_MESSAGE_ENABLED:
-            g_value_set_boolean (value, self->priv->status_message_enabled);
-            break;
         case PROP_STATUS_MESSAGE:
             g_value_set_string (value, self->priv->status_message);
             break;
-        case PROP_CYCLE_TIMEOUT:
-            g_value_set_long (value, self->priv->cycle_timeout);
-            break;
         case PROP_ACTIVE:
             g_value_set_boolean (value, self->priv->active);
             break;
@@ -924,69 +541,6 @@ gs_manager_class_init (GSManagerClass *klass) {
                                                            NULL,
                                                            FALSE,
                                                            G_PARAM_READABLE));
-    g_object_class_install_property (object_class,
-                                     PROP_LOCK_ENABLED,
-                                     g_param_spec_boolean ("lock-enabled",
-                                                           NULL,
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
-    g_object_class_install_property (object_class,
-                                     PROP_LOCK_WITH_SAVER_ENABLED,
-                                     g_param_spec_boolean ("lock-with-saver-enabled",
-                                                           NULL,
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
-    g_object_class_install_property (object_class,
-                                     PROP_LOCK_TIMEOUT,
-                                     g_param_spec_long ("lock-timeout",
-                                                        NULL,
-                                                        NULL,
-                                                        -1,
-                                                        G_MAXLONG,
-                                                        0,
-                                                        G_PARAM_READWRITE));
-    g_object_class_install_property (object_class,
-                                     PROP_LOGOUT_ENABLED,
-                                     g_param_spec_boolean ("logout-enabled",
-                                                           NULL,
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
-    g_object_class_install_property (object_class,
-                                     PROP_USER_SWITCH_ENABLED,
-                                     g_param_spec_boolean ("user-switch-enabled",
-                                                           NULL,
-                                                           NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
-
-    g_object_class_install_property (object_class,
-                                     PROP_LOGOUT_TIMEOUT,
-                                     g_param_spec_long ("logout-timeout",
-                                                        NULL,
-                                                        NULL,
-                                                        -1,
-                                                        G_MAXLONG,
-                                                        0,
-                                                        G_PARAM_READWRITE));
-    g_object_class_install_property (object_class,
-                                     PROP_LOGOUT_COMMAND,
-                                     g_param_spec_string ("logout-command",
-                                                          NULL,
-                                                          NULL,
-                                                          NULL,
-                                                          G_PARAM_READWRITE));
-    g_object_class_install_property (object_class,
-                                     PROP_CYCLE_TIMEOUT,
-                                     g_param_spec_long ("cycle-timeout",
-                                                        NULL,
-                                                        NULL,
-                                                        10000,
-                                                        G_MAXLONG,
-                                                        300000,
-                                                        G_PARAM_READWRITE));
     g_object_class_install_property (object_class,
                                      PROP_THROTTLED,
                                      g_param_spec_boolean ("throttled",
@@ -994,6 +548,13 @@ gs_manager_class_init (GSManagerClass *klass) {
                                                            NULL,
                                                            TRUE,
                                                            G_PARAM_READWRITE));
+    g_object_class_install_property (object_class,
+                                 PROP_STATUS_MESSAGE,
+                                 g_param_spec_string ("status-message",
+                                                      NULL,
+                                                      NULL,
+                                                      NULL,
+                                                      G_PARAM_READWRITE));
 }
 
 static void
@@ -1001,10 +562,11 @@ gs_manager_init (GSManager *manager) {
     manager->priv = gs_manager_get_instance_private (manager);
 
     manager->priv->grab = gs_grab_new ();
-    manager->priv->theme_manager = gs_theme_manager_new ();
 
     manager->priv->bg = xfce_bg_new ();
 
+    manager->priv->prefs = gs_prefs_new();
+
     xfce_bg_load_from_preferences (manager->priv->bg, NULL);
 
     add_deepsleep_idle(manager);
@@ -1187,26 +749,11 @@ window_map_event_cb (GSWindow  *window,
                      GdkEvent  *event,
                      GSManager *manager) {
     gs_debug ("Handling window map_event event");
-
     manager_maybe_grab_window (manager, window);
-
     manager_maybe_start_job_for_window (manager, window);
-
     return FALSE;
 }
 
-static void
-window_map_cb (GSWindow  *window,
-               GSManager *manager) {
-    gs_debug ("Handling window map event");
-}
-
-static void
-window_unmap_cb (GSWindow  *window,
-                 GSManager *manager) {
-    gs_debug ("Window unmapped!");
-}
-
 static void
 manager_show_window (GSManager *manager,
                      GSWindow  *window) {
@@ -1214,19 +761,18 @@ manager_show_window (GSManager *manager,
 
     job = gs_job_new_for_widget (gs_window_get_drawing_area (window));
 
-    manager_select_theme_for_job (manager, job);
     manager_add_job_for_window (manager, window, job);
 
     manager->priv->activate_time = time (NULL);
 
-    if (manager->priv->lock_timeout >= 0) {
+    if (manager->priv->prefs->lock_timeout >= 0) {
         remove_lock_timer (manager);
-        add_lock_timer (manager, manager->priv->lock_timeout);
+        add_lock_timer (manager, manager->priv->prefs->lock_timeout);
     }
 
-    if (manager->priv->cycle_timeout >= 10000) {
+    if (manager->priv->prefs->cycle >= 10000) {
         remove_cycle_timer (manager);
-        add_cycle_timer (manager, manager->priv->cycle_timeout);
+        add_cycle_timer (manager, manager->priv->prefs->cycle);
     }
 
     /* FIXME: only emit signal once */
@@ -1245,17 +791,6 @@ window_show_cb (GSWindow  *window,
     manager_show_window (manager, window);
 }
 
-static void
-maybe_set_window_throttle (GSManager *manager,
-                           GSWindow  *window,
-                           gboolean   throttled) {
-    if (throttled) {
-        manager_maybe_stop_job_for_window (manager, window);
-    } else {
-        manager_maybe_start_job_for_window (manager, window);
-    }
-}
-
 static void
 window_obscured_cb (GSWindow   *window,
                     GParamSpec *pspec,
@@ -1265,7 +800,11 @@ window_obscured_cb (GSWindow   *window,
     obscured = gs_window_is_obscured (window);
     gs_debug ("Handling window obscured: %s", obscured ? "obscured" : "unobscured");
 
-    maybe_set_window_throttle (manager, window, obscured);
+    if (obscured) {
+        manager_maybe_stop_job_for_window (manager, window);
+    } else {
+        manager_maybe_start_job_for_window (manager, window);
+    }
 }
 
 static void
@@ -1364,11 +903,9 @@ disconnect_window_signals (GSManager *manager,
     g_signal_handlers_disconnect_by_func (window, window_deactivated_cb, manager);
     g_signal_handlers_disconnect_by_func (window, window_activity_cb, manager);
     g_signal_handlers_disconnect_by_func (window, window_show_cb, manager);
-    g_signal_handlers_disconnect_by_func (window, window_map_cb, manager);
     g_signal_handlers_disconnect_by_func (window, window_map_event_cb, manager);
     g_signal_handlers_disconnect_by_func (window, window_obscured_cb, manager);
     g_signal_handlers_disconnect_by_func (window, window_dialog_up_changed_cb, manager);
-    g_signal_handlers_disconnect_by_func (window, window_unmap_cb, manager);
     g_signal_handlers_disconnect_by_func (window, window_grab_broken_cb, manager);
 }
 
@@ -1389,20 +926,17 @@ connect_window_signals (GSManager *manager,
                              G_CALLBACK (window_deactivated_cb), manager, 0);
     g_signal_connect_object (window, "show",
                              G_CALLBACK (window_show_cb), manager, G_CONNECT_AFTER);
-    g_signal_connect_object (window, "map",
-                             G_CALLBACK (window_map_cb), manager, G_CONNECT_AFTER);
     g_signal_connect_object (window, "map_event",
                              G_CALLBACK (window_map_event_cb), manager, G_CONNECT_AFTER);
     g_signal_connect_object (window, "notify::obscured",
                              G_CALLBACK (window_obscured_cb), manager, G_CONNECT_AFTER);
     g_signal_connect_object (window, "notify::dialog-up",
                              G_CALLBACK (window_dialog_up_changed_cb), manager, 0);
-    g_signal_connect_object (window, "unmap",
-                             G_CALLBACK (window_unmap_cb), manager, G_CONNECT_AFTER);
     g_signal_connect_object (window, "grab_broken_event",
                              G_CALLBACK (window_grab_broken_cb), manager, G_CONNECT_AFTER);
 }
 
+
 static void
 gs_manager_create_window_for_monitor (GSManager  *manager,
                                       GdkMonitor *monitor) {
@@ -1419,20 +953,9 @@ gs_manager_create_window_for_monitor (GSManager  *manager,
     gs_debug ("Creating a Window [%d,%d] (%dx%d) for monitor %d",
               rect.x, rect.y, rect.width, rect.height, manager_get_monitor_index (monitor));
 
-    window = gs_window_new (monitor,
-                            manager->priv->lock_enabled,
-                            manager->priv->lock_with_saver_enabled);
-
-    gs_window_set_user_switch_enabled (window, manager->priv->user_switch_enabled);
-    gs_window_set_logout_enabled (window, manager->priv->logout_enabled);
-    gs_window_set_logout_timeout (window, manager->priv->logout_timeout);
-    gs_window_set_logout_command (window, manager->priv->logout_command);
-    gs_window_set_keyboard_enabled (window, manager->priv->keyboard_enabled);
-    gs_window_set_keyboard_command (window, manager->priv->keyboard_command);
-    gs_window_set_status_message_enabled (window, manager->priv->status_message_enabled);
+    window = gs_window_new (monitor);
     gs_window_set_status_message (window, manager->priv->status_message);
     gs_window_set_lock_active (window, manager->priv->lock_active);
-
     connect_window_signals (manager, window);
 
     manager->priv->windows = g_slist_insert (manager->priv->windows, window, manager_get_monitor_index(monitor));
@@ -1521,11 +1044,6 @@ gs_manager_finalize (GObject *object) {
         g_object_unref (manager->priv->bg);
     }
 
-    free_themes (manager);
-    g_free (manager->priv->logout_command);
-    g_free (manager->priv->keyboard_command);
-    g_free (manager->priv->status_message);
-
     remove_deepsleep_idle (manager);
     remove_timers(manager);
 
@@ -1537,11 +1055,8 @@ gs_manager_finalize (GObject *object) {
 
     manager->priv->active = FALSE;
     manager->priv->activate_time = 0;
-    manager->priv->lock_enabled = FALSE;
-    manager->priv->lock_with_saver_enabled = FALSE;
 
     g_object_unref (manager->priv->grab);
-    g_object_unref (manager->priv->theme_manager);
 
     G_OBJECT_CLASS (gs_manager_parent_class)->finalize (object);
 }
